@@ -21,4 +21,4 @@ class JenkinsLogger:
         self.logger.addHandler(handler)
 
     def send(self, message):
-        self.logger.info(message + 'matt was here')
+        self.logger.info(message + 'final x4 version')
